@@ -36,6 +36,7 @@ warnings.filterwarnings("ignore", "Accessed deprecated property",
 
 import apt_pkg
 import distro_info
+import json
 import os
 import subprocess
 import sys
@@ -64,7 +65,7 @@ from .Core.AlertWatcher import AlertWatcher
 from .Core.MyCache import MyCache
 from .Core.roam import NetworkManagerHelper
 from .Core.UpdateList import UpdateList
-from .Core.utils import get_arch, get_dist
+from .Core.utils import get_arch, get_dist, SoftwarePropertiesPage
 from .backend import (InstallBackend,
                       get_backend)
 
@@ -85,6 +86,7 @@ class UpdateManager(Gtk.Window):
         self.unity = UnitySupport()
         self.controller = None
         self.cache = None
+        self.ua_security_packages = []
         self.update_list = None
         self.meta_release = None
         self.hwe_replacement_packages = None
@@ -193,13 +195,13 @@ class UpdateManager(Gtk.Window):
         self._start_pane(None)
         sys.exit(0)
 
-    def show_settings(self):
+    def show_settings(self, page_number=SoftwarePropertiesPage.updates):
         try:
             apt_pkg.pkgsystem_unlock()
         except SystemError:
             pass
         cmd = ["/usr/bin/software-properties-gtk",
-               "--open-tab", "2"]
+               "--open-tab", str(page_number)]
 
         if "WAYLAND_DISPLAY" not in os.environ:
             cmd += ["--toplevel", "%s" % self.get_window().get_xid()]
@@ -247,23 +249,41 @@ class UpdateManager(Gtk.Window):
                                          cancelled_update, error_occurred)
         self._start_pane(pane)
 
+    def _get_ua_security_status(self):
+        self.ua_security_packages = []
+        try:
+            p = subprocess.Popen(['pro', 'security-status', '--format=json'],
+                                 stdout=subprocess.PIPE)
+        except OSError:
+            pass
+        else:
+            while p.poll() is None:
+                while Gtk.events_pending():
+                    Gtk.main_iteration()
+                time.sleep(0.05)
+            s = json.load(p.stdout)
+            for package in s.get('packages', []):
+                if package.get('service_name', '') == 'standard-security':
+                    continue
+                status = package.get('status', '')
+                if (
+                    status == 'pending_attach'
+                    or status == 'pending_enable'
+                    or status == 'upgrade_available'
+                ):
+                    name = package.get('package', '')
+                    version = package.get('version', '')
+                    size = package.get('download_size', 0)
+                    downloadable = status == 'upgrade_available'
+                    self.ua_security_packages.append(
+                        (name, version, size, downloadable)
+                    )
+            self.cache.create_pro_cache(self.ua_security_packages)
+
     def _make_available_pane(self, install_count, need_reboot=False,
                              cancelled_update=False, error_occurred=False):
         self._check_hwe_support_status()
-        if install_count == 0:
-            # Need Restart > New Release > No Updates
-            if need_reboot:
-                return NeedRestartDialog(self)
-            dist_upgrade = self._check_meta_release()
-            if dist_upgrade:
-                return dist_upgrade
-            elif cancelled_update:
-                return StoppedUpdatesDialog(self)
-            elif self.hwe_replacement_packages:
-                return HWEUpgradeDialog(self)
-            else:
-                return NoUpdatesDialog(self, error_occurred=error_occurred)
-        else:
+        if install_count != 0 or len(self.ua_security_packages) > 0:
             header = None
             desc = None
             if error_occurred:
@@ -276,6 +296,19 @@ class UpdateManager(Gtk.Window):
             elif self.hwe_replacement_packages:
                 return HWEUpgradeDialog(self)
             return UpdatesAvailable(self, header, desc, need_reboot)
+        else:
+            # Need Restart > New Release > No Updates
+            if need_reboot:
+                return NeedRestartDialog(self)
+            dist_upgrade = self._check_meta_release()
+            if dist_upgrade:
+                return dist_upgrade
+            elif cancelled_update:
+                return StoppedUpdatesDialog(self)
+            elif self.hwe_replacement_packages:
+                return HWEUpgradeDialog(self)
+            else:
+                return NoUpdatesDialog(self, error_occurred=error_occurred)
 
     def start_error(self, update_and_retry, header, desc):
         if update_and_retry:
@@ -406,9 +439,13 @@ class UpdateManager(Gtk.Window):
                 Gtk.main_iteration()
         iterate()
 
+        self._get_ua_security_status()
+
         self.update_list = UpdateList(self)
         try:
-            self.update_list.update(self.cache, eventloop_callback=iterate)
+            self.update_list.update(self.cache, eventloop_callback=iterate,
+                                    ua_security_packages=self.
+                                    ua_security_packages)
         except SystemError as e:
             header = _("Could not calculate the upgrade")
             desc = _("An unresolvable problem occurred while "
